==> selenium-api-2.14.0-sources.jar: org/openqa/selenium/Beta.java <==
/*
Copyright 2011 WebDriver committers
Copyright 2011 Google Inc.
Copyright 2011 Software Freedom Conservancy

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.openqa.selenium;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Indicates that a feature or API is in active development, and so should not
 * be relied upon. The update policy for anything marked beta is that it may be
 * deleted in the next Selenium release without warning.
 *
 * In the ideal world, this would cause the method to blink gently in the user's
 * IDE. We don't live in the ideal world. We'll find out the hard way whether
 * reading docs is the same thing.
 */
@Retention(RetentionPolicy.CLASS)
@Target({
    ElementType.ANNOTATION_TYPE,
    ElementType.CONSTRUCTOR,
    ElementType.FIELD,
    ElementType.METHOD,
    ElementType.TYPE})
@Documented
public @interface Beta {}

==> selenium-api-2.21.0-sources.jar: org/openqa/selenium/Beta.java <==
/*
Copyright 2011 WebDriver committers
Copyright 2011 Google Inc.
Copyright 2011 Software Freedom Conservancy

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.openqa.selenium;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Indicates that a feature or API is in active development, and so should not
 * be relied upon. The update policy for anything marked beta is that it may be
 * deleted in the next Selenium release without warning.
 *
 * In the ideal world, this would cause the method to blink gently in the user's
 * IDE. We don't live in the ideal world. We'll find out the hard way whether
 * reading docs is the same thing.
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({
    ElementType.ANNOTATION_TYPE,
    ElementType.CONSTRUCTOR,
    ElementType.FIELD,
    ElementType.METHOD,
    ElementType.TYPE})
@Documented
public @interface Beta {}
